@@ -27,7 +27,8 @@ impl<'a> Network<'a> {
     match Kubeconfig::read() {
       Ok(config) => {
         let mut app = self.app.lock().await;
-        app.set_contexts(contexts::get_contexts(&config));
+        let selected_ctx = app.data.selected.context.to_owned();
+        app.set_contexts(contexts::get_contexts(&config, selected_ctx));
         app.data.kubeconfig = Some(config);
       }
       Err(e) => {
@@ -154,6 +155,18 @@ impl<'a> Network<'a> {
       .await;
 
     let mut app = self.app.lock().await;
+    if app.data.selected.pod.is_some() {
+      let containers = &items.iter().find_map(|pod| {
+        if pod.name == app.data.selected.pod.clone().unwrap() {
+          Some(&pod.containers)
+        } else {
+          None
+        }
+      });
+      if containers.is_some() {
+        app.data.containers.set_items(containers.unwrap().clone());
+      }
+    }
     app.data.pods.set_items(items);
   }
 
@@ -225,7 +238,7 @@ impl<'a> Network<'a> {
     <K as KubeResource>::DynamicType: Default,
   {
     let app = self.app.lock().await;
-    match &app.data.selected_ns {
+    match &app.data.selected.ns {
       Some(ns) => Api::namespaced(self.client.clone(), &ns),
       None => Api::all(self.client.clone()),
     }
